Installation notes
------------------

Python3 modules:
* gevent
* karellen-geventws (python3-compatible fork of gevent-websocket)
* bottle
* numpy >= 1.14.2
* psycopg2
* pony==0.7.2 (0.7.3 causes issues)
* websocket-client (optional, only for running web API tests)

